import request from '@/utils/request'

//首页-化学品柜统计数据
export function chemicalIndexTypeGroup(query) {
  return request({
    url: '/chemical/index/typeGroup',
    method: 'get',
    params: query
  })
}
//首页-类别占比
export function chemicalIndexChemicalGroup(query) {
  return request({
    url: '/chemical/index/chemicalGroup',
    method: 'get',
    params: query
  })
}
//首页-使用统计
export function chemicalIndexUseCount(query) {
  return request({
    url: '/chemical/index/useCount',
    method: 'get',
    params: query
  })
}
//首页-库存统计
export function chemicalIndexStockCount(query) {
  return request({
    url: '/chemical/index/stockCount',
    method: 'get',
    params: query
  })
}
//首页-使用量top6
export function chemicalIndexUseTotalCount(query) {
  return request({
    url: '/chemical/index/useTotalCount ',
    method: 'get',
    params: query
  })
}
//首页-报警统计
export function chemicalIndexWarnCount(query) {
  return request({
    url: '/chemical/index/warnCount',
    method: 'get',
    params: query
  })
}
//首页-厂家模糊查询
export function chemicalAioSearchProducer(query) {
  return request({
    url: '/chemical/aio/selectProducer',
    method: 'get',
    params: query
  })
}

//首页-管控级别
export function chemicalIndexManageLevel(query) {
  return request({
    url: '/chemical/index/manageLevel ',
    method: 'get',
    params: query
  })
}

//msds-列表
export function chemicalMsdsList(data) {
  return request({
    url: '/chemical/msds/list',
    method: 'post',
    data: data
  })
}

//msds-新增
export function chemicalMsdsAdd(data) {
  return request({
    url: '/chemical/msds/add',
    method: 'post',
    data: data
  })
}

//msds-编辑
export function chemicalMsdsEdit(data) {
  return request({
    url: '/chemical/msds/edit',
    method: 'post',
    data: data
  })
}

//msds-删除
export function chemicalMsdsDel(data) {
  return request({
    url: '/chemical/msds/del',
    method: 'post',
    data: data
  })
}

//msds-详情
export function chemicalMsdsDetail(query) {
  return request({
    url: '/chemical/msds/detail',
    method: 'get',
    params: query
  })
}

//化学品基础配置
export function chemicalBasicConfigList(query) {
  return request({
    url: '/chemical/basicConfig/list',
    method: 'get',
    params: query
  })
}

//化学品基础配置提交
export function chemicalBasicConfigAdd(data) {
  return request({
    url: '/chemical/basicConfig/add',
    method: 'post',
    data: data
  })
}
/************************* 化学品 ***************************/
//化学品-列表
export function chemicalChemicalList(data) {
  return request({
    url: '/chemical/chemical/list',
    method: 'post',
    data: data
  })
}
//化学品-新增
export function chemicalChemicalAdd(data) {
  return request({
    url: '/chemical/chemical/add',
    method: 'post',
    data: data
  })
}
//化学品-编辑
export function chemicalChemicalUpdate(data) {
  return request({
    url: '/chemical/chemical/update',
    method: 'post',
    data: data
  })
}
//化学品-删除
export function chemicalChemicalDelete(data) {
  return request({
    url: '/chemical/chemical/delete',
    method: 'post',
    data: data
  })
}
//化学品-详情
export function chemicalChemicalDetail(query) {
  return request({
    url: '/chemical/chemical/detail',
    method: 'get',
    params: query
  })
}
//化学品-关联MSDS查询
export function chemicalMsdsDetailByMsds(data) {
  return request({
    url: '/chemical/msds/detailByMsds',
    method: 'post',
    data: data
  })
}
//化学品-关联MSDS提交
export function chemicalChemicalUpdateMsds(data) {
  return request({
    url: '/chemical/chemical/updateMsds',
    method: 'post',
    data: data
  })
}

//化学品柜-列表
export function chemicalCabinetList(data) {
  return request({
    url: '/chemical/cabinet/list',
    method: 'post',
    data: data
  })
}
//化学品柜-新增
export function chemicalCabinetAdd(data) {
  return request({
    url: '/chemical/cabinet/add',
    method: 'post',
    data: data
  })
}
//化学品柜-编辑
export function chemicalCabinetUpdate(data) {
  return request({
    url: '/chemical/cabinet/update',
    method: 'post',
    data: data
  })
}
//化学品柜-详情
export function chemicalCabinetDetail(query) {
  return request({
    url: '/chemical/cabinet/detail',
    method: 'get',
    params: query
  })
}
//化学品柜-删除判断
export function chemicalStockGetStockByDoorId(query) {
  return request({
    url: '/chemical/stock/getStockByDoorId',
    method: 'get',
    params: query
  })
}
//化学品柜-过滤柜锁
export function chemicalCabinetGetLockList(query) {
  return request({
    url: '/chemical/cabinet/getLockList',
    method: 'get',
    params: query
  })
}
//化学品柜-删除
export function chemicalCabinetDelete(data) {
  return request({
    url: '/chemical/cabinet/delete',
    method: 'post',
    data: data
  })
}
//化学品柜-化学品-柜门列表
export function chemicalCabinetGetDoorList(query) {
  return request({
    url: '/chemical/cabinet/getDoorList',
    method: 'get',
    params: query
  })
}
//化学品柜-业务类型下拉列表
export function chemicalLockLogLockTypeList(query) {
  return request({
    url: '/chemical/lockLog/lockTypeList',
    method: 'get',
    params: query
  })
}
//化学品柜-开门记录
export function chemicalLockLogLockList(data) {
  return request({
    url: '/chemical/lockLog/list',
    method: 'post',
    data: data
  })
}
//化学品柜-化学品-列表
export function chemicalStockStockUse(data) {
  return request({
    url: '/chemical/stock/stockUse',
    method: 'post',
    data: data
  })
}
//审核流程-提交
export function chemicalAuditConfigAdd(data) {
  return request({
    url: '/chemical/auditConfig/add',
    method: 'post',
    data: data
  })
}
//审核流程-配置查询接口
export function chemicalAuditConfigGetConfigList(data) {
  return request({
    url: '/chemical/auditConfig/getConfigList',
    method: 'post',
    data: data
  })
}

//申购登记-查询化学品列表
export function chemicalChemicalGetList(data) {
  return request({
    url: '/chemical/chemical/getList',
    method: 'post',
    data: data
  })
}
//申购登记-查询当前账号申购人,导师,课题组
export function chemicalApplyGetUserInfo(query) {
  return request({
    url: '/chemical/apply/getUserInfo',
    method: 'get',
    params: query
  })
}
//申购登记-查询课题组列表
export function systemTopicTopicList(data) {
  return request({
    url: '/system/topic/topicList',
    method: 'post',
    data: data
  })
}

//申购登记-新增
export function chemicalApplyAdd(data) {
  return request({
    url: '/chemical/apply/add',
    method: 'post',
    data: data
  })
}
//申购登记-修改
export function chemicalApplyUpdate(data) {
  return request({
    url: '/chemical/apply/update',
    method: 'post',
    data: data
  })
}
//申购登记-列表
export function chemicalApplyList(data) {
  return request({
    url: '/chemical/apply/list',
    method: 'post',
    data: data
  })
}
//申购登记-详情
export function chemicalApplyDetail(query) {
  return request({
    url: '/chemical/apply/detail',
    method: 'get',
    params: query
  })
}
//申购登记-撤销
export function chemicalApplyRevoke(data) {
  return request({
    url: '/chemical/apply/revoke',
    method: 'post',
    data: data
  })
}
//申购登记-删除
export function chemicalApplyDelete(data) {
  return request({
    url: '/chemical/apply/delete',
    method: 'post',
    data: data
  })
}
//申购登记-批量提交
export function chemicalApplyBatchSubmit(data) {
  return request({
    url: '/chemical/apply/batchSubmit',
    method: 'post',
    data: data
  })
}
//申购审核-列表
export function chemicalApplyApproveList(data) {
  return request({
    url: '/chemical/apply/approveList',
    method: 'post',
    data: data
  })
}
//申购审核-提交
export function chemicalApplyTaskApprovalTask(data) {
  return request({
    url: '/chemical/applyTask/approvalTask',
    method: 'post',
    data: data
  })
}
//待入库-列表
export function chemicalStockWaitList(data) {
  return request({
    url: '/chemical/stockWait/list',
    method: 'post',
    data: data
  })
}
//待入库-新增
export function chemicalStockWaitAdd(data) {
  return request({
    url: '/chemical/stockWait/add',
    method: 'post',
    data: data
  })
}
//待入库-编辑
export function chemicalStockWaitUpdate(data) {
  return request({
    url: '/chemical/stockWait/update',
    method: 'post',
    data: data
  })
}
//待入库-详情
export function chemicalStockWaitDetail(query) {
  return request({
    url: '/chemical/stockWait/detail',
    method: 'get',
    params: query
  })
}
//待入库-删除
export function chemicalStockWaitDelete(data) {
  return request({
    url: '/chemical/stockWait/delete',
    method: 'post',
    data: data
  })
}
//待入库-过期时间
export function chemicalStockWaitUpdateByExpire(data) {
  return request({
    url: '/chemical/stockWait/updateByExpire',
    method: 'post',
    data: data
  })
}
//待入库-同步
export function chemicalStockWaitUpdateStockWait(data) {
  return request({
    url: '/chemical/stockWait/updateStockWait',
    method: 'post',
    data: data
  })
}
//实验室-固体液体液体已存储量
export function chemicalStockGetStockBysubId(query) {
  return request({
    url: '/chemical/stock/getStockBysubId',
    method: 'get',
    params: query
  })
}
//实验室-实验室现有库存
export function chemicalStockStockListBySubId(query) {
  return request({
    url: '/chemical/stock/stockListBySubId',
    method: 'get',
    params: query
  })
}
//预警通知-危险源预警-详情
export function systemWarningConfigDetail(query) {
  return request({
    url: '/system/warningConfig/detail',
    method: 'get',
    params: query
  })
}
//预警通知-危险源预警-修改
export function systemWarningConfigUpdate(data) {
  return request({
    url: '/system/warningConfig/update',
    method: 'post',
    data: data
  })
}
//预警通知-算法预警-详情
export function systemConfigAlgorithmDetail(query) {
  return request({
    url: '/system/configAlgorithm/detail',
    method: 'get',
    params: query
  })
}
//预警通知-算法预警-修改
export function systemConfigAlgorithmUpdate(data) {
  return request({
    url: '/system/configAlgorithm/update',
    method: 'post',
    data: data
  })
}

//预警通知-危险源预警-预警升级规则-新增
export function systemConfigRuleAdd(data) {
  return request({
    url: '/system/configRule/add',
    method: 'post',
    data: data
  })
}
//预警通知-危险源预警-预警升级规则-修改
export function systemConfigRuleUpdate(data) {
  return request({
    url: '/system/configRule/update',
    method: 'post',
    data: data
  })
}
//预警通知-危险源预警-预警升级规则-删除
export function systemConfigRuleDelete(data) {
  return request({
    url: '/system/configRule/delete',
    method: 'post',
    data: data
  })
}
//预警通知-危险源预警-预警升级规则-列表
export function systemConfigRuleList(data) {
  return request({
    url: '/system/configRule/list',
    method: 'post',
    data: data
  })
}
//预警通知-危险源预警-预警升级规则-详情
export function systemConfigRuleDetail(query) {
  return request({
    url: '/system/configRule/detail',
    method: 'get',
    params: query
  })
}
//预警通知-危险源预警-预警升级规则-启用停用
export function systemConfigRuleEnableOrDisable(data) {
  return request({
    url: '/system/configRule/enableOrDisable',
    method: 'post',
    data: data
  })
}
//预警通知-列表
export function systemWarningNoticeWarningList(data) {
  return request({
    url: '/system/warningNotice/warningList',
    method: 'post',
    data: data
  })
}
//预警通知-详情
export function systemWarningNoticeDetail(query) {
  return request({
    url: '/system/warningNotice/detail',
    method: 'get',
    params: query
  })
}
//预警通知-处理
export function systemWarningNoticeHandleMessage(data) {
  return request({
    url: '/system/warningNotice/handleMessage',
    method: 'post',
    data: data
  })
}
//使用台账-列表
export function chemicalUserecordList(data) {
  return request({
    url: '/chemical/userecord/list',
    method: 'post',
    data: data
  })
}
//使用台账-化学品柜列表
export function chemicalCabinetSelect(data) {
  return request({
    url: '/chemical/cabinet/select',
    method: 'post',
    data: data
  })
}
//使用台账-详情
export function chemicalUserecordDetail(query) {
  return request({
    url: '/chemical/userecord/detail',
    method: 'get',
    params: query
  })
}
//预警事件-列表
export function systemWarningNoticeList(data) {
  return request({
    url: '/system/warningNotice/list',
    method: 'post',
    data: data
  })
}
//预警事件-详情
export function systemWarningNoticeWarningDetail(query) {
  return request({
    url: '/system/warningNotice/warningDetail',
    method: 'get',
    params: query
  })
}
//预警事件-处理
export function systemWarningNoticeWarningHandleMessage(data) {
  return request({
    url: '/system/warningNotice/warningHandleMessage',
    method: 'post',
    data: data
  })
}
//入库记录-列表
export function chemicalStockListIn(data) {
  return request({
    url: '/chemical/stock/listIn',
    method: 'post',
    data: data
  })
}
//出库记录-列表
export function chemicalStockListOut(data) {
  return request({
    url: '/chemical/stock/listOut',
    method: 'post',
    data: data
  })
}
//库存统计-库存明细-列表
export function chemicalStockStockDetailsList(data) {
  return request({
    url: '/chemical/stock/stockDetailsList',
    method: 'post',
    data: data
  })
}
//库存统计-库存明细-详情
export function chemicalStockStockDetails(query) {
  return request({
    url: '/chemical/stock/stockDetails',
    method: 'get',
    params: query
  })
}
//库存统计-汇总统计-列表
export function chemicalStockStockCollectList(data) {
  return request({
    url: '/chemical/stock/stockCollectList',
    method: 'post',
    data: data
  })
}
//库存统计-汇总统计-详情列表
export function chemicalStockStockCollectDetailsList(data) {
  return request({
    url: '/chemical/stock/stockCollectDetailsList',
    method: 'post',
    data: data
  })
}










